.. Copyright (c) 2018, Voilà Contributors
   Copyright (c) 2018, QuantStack

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

.. _install:

================
Installing Voilà
================

Voilà can be installed with the ``mamba`` or ``conda`` package manager

.. code-block:: bash

   mamba install -c conda-forge voila

or from ``PyPI``:

.. code-block:: bash

   pip install voila

Once Voilà is installed, it can be used either as a Command-Line Interface,
or as a Jupyter Server extension. See :ref:`using` for information on how to use Voilà.
